@@ -1,4 +1,5 @@
 description_NCA<-function(){
+cat("\n\n")
 cat("****************************************************************************\n")
 cat("                      Noncompartmental analysis (NCA)                      \n")
 cat("----------------------------------------------------------------------------\n")
@@ -10,4 +11,6 @@ cat(" of the last measurable Cp to time infinity) is equal to the last measurabl
 cat(" Cp divided by lambda_z.                                                    \n")
 cat("****************************************************************************\n")
 cat("\n")
+alarm(); alarm()
+readline(" Press Enter to continue...")
 }
\ No newline at end of file
