@@ -1,4 +1,4 @@
 #description of NCA csv import for replicated study
 description_RepNCAcsv<-function(){
-description_NCAcsv(replicated=TRUE)
+description_NCAcsv(replicated=TRUE, parallel=FALSE)
 }
\ No newline at end of file
