@@ -14,10 +14,10 @@ if(lnAUC0INF){
  theta2<-lnAUC0INF_theta2
  }  
 cat("**Interpretation:\n")
-cat("Ho: Theta =< ",theta1," or  Theta >= ",formatC(theta2,format="f",digits=2), "\n")
-cat("Ha: ",theta1," < Theta < ",formatC(theta2,format="f",digits=2),"\n")
-cat("Theta = Mean_test/Mean_ref  \n")
+cat("Ho: Theta < ",formatC(theta1,format="f",digits=5)," or  Theta > ",formatC(theta2,format="f",digits=5), "\n")
+cat("Ha: ",formatC(theta1,format="f",digits=5)," < or = Theta < or = ",formatC(theta2,format="f",digits=5),"\n")
+cat("where Theta = Mean_Test/Mean_Ref.\n")
 cat("Because all P values are less than 0.05, we will reject the null hypothesis (Ho). \n")
-cat("BE acceptance range is set at",formatC(theta1*100,format="f",digits=2),"% - ",formatC(theta2*100,format="f",digits=2),"% .\n")
+cat("BE acceptance criterion is set within the range of ",formatC(theta1*100,format="f",digits=3)," - ",formatC(theta2*100,format="f",digits=3),"% .\n")
 cat("\n")
 }
\ No newline at end of file
